@@ -15,9 +15,9 @@
 from typing import Callable, Union
 
 import tensorflow as tf
+from check_shapes import check_shapes
 
 from ...base import TensorType
-from ...experimental.check_shapes import check_shapes
 from ...inducing_variables import (
     FallbackSeparateIndependentInducingVariables,
     FallbackSharedIndependentInducingVariables,
