@@ -17,10 +17,10 @@ from typing import Optional
 
 import tensorflow as tf
 import tensorflow_probability as tfp
+from check_shapes import Shape, check_shapes
 from deprecated import deprecated
 
 from ..base import Module, Parameter, TensorData, TensorType
-from ..experimental.check_shapes import ErrorContext, Shape, check_shapes, register_get_shape
 from ..utilities import positive
 
 
@@ -60,11 +60,6 @@ class InducingVariables(Module, abc.ABC):
         """
 
 
-@register_get_shape(InducingVariables)
-def get_scalar_shape(shaped: InducingVariables, context: ErrorContext) -> Shape:
-    return shaped.shape
-
-
 class InducingPointsBase(InducingVariables):
     @check_shapes(
         "Z: [M, D]",
