@@ -16,11 +16,11 @@ from typing import Optional, Sequence, cast
 
 import numpy as np
 import tensorflow as tf
+from check_shapes import check_shape as cs
+from check_shapes import check_shapes, inherit_check_shapes
 
 from ..base import Parameter, TensorType
 from ..config import default_float
-from ..experimental.check_shapes import check_shape as cs
-from ..experimental.check_shapes import check_shapes, inherit_check_shapes
 from ..utilities import to_default_float
 from .base import Kernel
 
