@@ -15,9 +15,9 @@
 from typing import Optional
 
 import tensorflow as tf
+from check_shapes import check_shapes, inherit_check_shapes
 
 from ..base import Parameter, TensorType
-from ..experimental.check_shapes import check_shapes, inherit_check_shapes
 from ..utilities import positive
 from .base import ActiveDims, Kernel
 
