@@ -16,10 +16,10 @@ from typing import Optional
 
 import numpy as np
 import tensorflow as tf
+from check_shapes import check_shape as cs
+from check_shapes import check_shapes, inherit_check_shapes
 
 from ..base import AnyNDArray, Parameter, TensorType
-from ..experimental.check_shapes import check_shape as cs
-from ..experimental.check_shapes import check_shapes, inherit_check_shapes
 from ..utilities import positive, to_default_float
 from .base import ActiveDims, Kernel
 
