@@ -15,11 +15,11 @@
 import numpy as np
 import pytest
 import tensorflow as tf
+from check_shapes import ShapeChecker
 
 import gpflow
 from gpflow.base import AnyNDArray
 from gpflow.config import default_float
-from gpflow.experimental.check_shapes import ShapeChecker
 
 rng = np.random.RandomState(0)
 
